==> fwbuilder_2.1.19.orig.tar.gz: fwbuilder-2.1.19/src/gui/iosaclAdvancedDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2004 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: iosaclAdvancedDialog.h,v 1.1 2007/05/09 04:18:18 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#ifndef __IOSACLADVANCEDDIALOG_H_
#define __IOSACLADVANCEDDIALOG_H_

#include "iosacladvanceddialog_q.h"
#include "DialogData.h"

#include <string>

class QWidget;
class QSpinBox;
class QComboBox;
class QCheckBox;
class QProcess;

namespace libfwbuilder {
    class FWObject;
};

class iosaclAdvancedDialog : public iosaclAdvancedDialog_q
{
    Q_OBJECT

    libfwbuilder::FWObject          *obj;
    DialogData                       data;
    
 public:
    iosaclAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);

protected slots:

    virtual void accept();
    virtual void reject();

    virtual void editProlog();
    virtual void editEpilog();

    virtual void scriptACLModeChanged();
    
};

#endif // __IOSACLADVANCEDDIALOG_H

==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/gui/iosaclAdvancedDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2004 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: iosaclAdvancedDialog.h 488 2008-08-27 15:23:46Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#ifndef __IOSACLADVANCEDDIALOG_H_
#define __IOSACLADVANCEDDIALOG_H_

#include <ui_iosacladvanceddialog_q.h>
#include "DialogData.h"
#include <QDialog>

#include <string>

class QWidget;
class QSpinBox;
class QComboBox;
class QCheckBox;
class QProcess;

namespace libfwbuilder {
    class FWObject;
};

class iosaclAdvancedDialog : public QDialog
{
    Q_OBJECT

    libfwbuilder::FWObject          *obj;
    DialogData                       data;
    Ui::iosaclAdvancedDialog_q      *m_dialog;
    
 public:
    iosaclAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
    ~iosaclAdvancedDialog();

protected slots:

    virtual void accept();
    virtual void reject();

    virtual void editProlog();
    virtual void editEpilog();

    virtual void scriptACLModeChanged();
    virtual void toggleGenerateLogging();
};

#endif // __IOSACLADVANCEDDIALOG_H
